#!/usr/bin/env node
'use strict';

import fs from 'fs';
import path from 'path';
import glob from 'glob';
import chalk from 'chalk';
import jsonlint from 'jsonlint';

const argv = require('minimist')(process.argv.slice(2));

const targetPath = argv.path;
const pattern = argv.pattern || '**/*.json';

function lint () {

	if ( !path ) {
		return console.log('Please provide --path');
	}

	if ( !~pattern.indexOf('.json') ) {
		return console.log('Pattern needs to look for .json files');
	}

	if ( path ) {

		const schema = require('./draft-04-schema.json');
		const target = path.join(targetPath, pattern);

		console.log('');
		console.log('Pattern:');
		console.log(chalk.green(target));

		let count = 0;
		const files = glob.sync(target);

		files.forEach((file) => {

			const fileContent = fs.readFileSync(file, { encoding: 'utf-8' });

			if ( fileContent ) {

				try {
					jsonlint.parse(fileContent);
				} catch ( err ) {
					count++;
					console.log('');
					console.log(chalk.underline.red(count, file));
					console.log(err);
					console.log('');
				}

			}

		});
		console.log('----------------------------------------------');
		console.log('Found errors in', chalk.red(count), 'files');
		console.log('----------------------------------------------');

	}

}

lint();
